package com.gic.evaluate.service.impl;

import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.constants.Constants;
import com.gic.evaluate.constant.ComputeEnum;
import com.gic.evaluate.constant.QuickReplyTypeEnum;
import com.gic.evaluate.dao.mapper.TabEvaluateMapper;
import com.gic.evaluate.dto.EvaluateDTO;
import com.gic.evaluate.entity.TabEvaluate;
import com.gic.evaluate.qo.EvaluateQO;
import com.gic.evaluate.qo.StoreScoreQO;
import com.gic.evaluate.qo.StoreTrendQO;
import com.gic.evaluate.service.EvaluateService;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019-12-27 9:54
 */
@Service
public class EvaluateServiceImpl implements EvaluateService {

    @Autowired
    private TabEvaluateMapper tabEvaluateMapper;

    @Override
    public Page<TabEvaluate> listEvaluate(EvaluateQO evaluateQO) {
        if (evaluateQO.getGoodsType() != null) {
            evaluateQO.setGoodsCompute(ComputeEnum.parseCodeToCompute(evaluateQO.getGoodsType()));
        }
        if (evaluateQO.getStoreType() != null) {
            evaluateQO.setStoreCompute(ComputeEnum.parseCodeToCompute(evaluateQO.getStoreType()));
        }
        if (evaluateQO.getServiceType() != null) {
            evaluateQO.setServiceCompute(ComputeEnum.parseCodeToCompute(evaluateQO.getServiceType()));
        }
        PageHelper.startPage(evaluateQO.getCurrentPage(), evaluateQO.getPageSize());
        return tabEvaluateMapper.listEvaluate(evaluateQO);
    }

    @Override
    public TabEvaluate getEvaluate(Integer enterpriseId, Integer evaluateId) {
        TabEvaluate evaluate = this.tabEvaluateMapper.selectByPrimaryKey(evaluateId);
        if (evaluate != null && Constants.NORMAL_STATUS.equals(evaluate.getStatus()) && evaluate.getEnterpriseId().equals(enterpriseId)) {
            return evaluate;
        }
        return null;
    }

    @Override
    public void saveEvaluate(EvaluateDTO evaluateDTO) {
        TabEvaluate evaluate = EntityUtil.changeEntityByJSON(TabEvaluate.class, evaluateDTO);
        evaluate.setStatus(Constants.NORMAL_STATUS);
        evaluate.setCreateTime(new Date());
        tabEvaluateMapper.insertSelective(evaluate);
    }

    @Override
    public void updateShowStatus(Integer enterpriseId, List<Integer> evaluateId, Integer showStatus) {
        tabEvaluateMapper.updateShowStatus(enterpriseId, evaluateId, showStatus);
    }

    @Override
    public void updateTopHotStatus(Integer enterpriseId, Integer evaluateId, Integer topHotStatus) {
        tabEvaluateMapper.updateTopHotStatus(enterpriseId, evaluateId, topHotStatus);
    }

    @Override
    public void updateMaliciousStatus(Integer enterpriseId, Integer evaluateId, Integer maliciousStatus) {
        tabEvaluateMapper.updateMaliciousStatus(enterpriseId, evaluateId, maliciousStatus);
    }

    @Override
    public Map<String, Long> getTotalCountChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.getTotalChart(enterpriseId, startTime, endTime);
    }

    @Override
    public Map<String, Long> getGoodsCountChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.getGoodsCountChart(enterpriseId, startTime, endTime);
    }

    @Override
    public Map<String, Long> getStoreCountChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.getStoreCountChart(enterpriseId, startTime, endTime);
    }

    @Override
    public Map<String, Long> getServiceCountChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.getServiceCountChart(enterpriseId, startTime, endTime);
    }

    @Override
    public List<Map<String, String>> listTrendTotalEvaluate(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.listTrendEvaluate(enterpriseId, startTime, endTime, null);
    }

    @Override
    public List<Map<String, String>> listTrendGoodEvaluate(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.listTrendEvaluate(enterpriseId, startTime, endTime, Constants.NORMAL_STATUS);
    }

    @Override
    public List<Map<String, Object>> listStoreScore(StoreScoreQO storeScoreQO) {
        PageHelper.startPage(storeScoreQO);
        return tabEvaluateMapper.listStoreScore(storeScoreQO);
    }

    @Override
    public Map<String, Object> getTotalStoreScore(StoreScoreQO storeScoreQO) {
        PageHelper.startPage(storeScoreQO);
        return tabEvaluateMapper.getTotalStoreScore(storeScoreQO);
    }

    @Override
    public List<Map<String, Object>> listTrend(StoreTrendQO storeTrendQO) {
        return tabEvaluateMapper.listTrend(storeTrendQO);
    }

    @Override
    public TabEvaluate getEvaluateByOrderNumber(Integer enterpriseId, String orderNumber) {
        return tabEvaluateMapper.getEvaluateByOrderNumber(enterpriseId, orderNumber);
    }

    @Override
    public void updateEvaluate(EvaluateDTO evaluateDTO) {
        TabEvaluate evaluate = EntityUtil.changeEntityByJSON(TabEvaluate.class, evaluateDTO);
        tabEvaluateMapper.updateByPrimaryKeySelective(evaluate);
    }

    @Override
    public List<Map<String, Object>> evaluateGoodQuickChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.evaluateQuickChart(enterpriseId, startTime, endTime, QuickReplyTypeEnum.GOOD.getCode());
    }

    @Override
    public List<Map<String, Object>> evaluateBadQuickChart(Integer enterpriseId, String startTime, String endTime) {
        return tabEvaluateMapper.evaluateQuickChart(enterpriseId, startTime, endTime, QuickReplyTypeEnum.BAD.getCode());
    }
}
