package com.gic.evaluate.service.outer.impl;

import com.gic.api.base.commons.Page;
import com.gic.api.base.commons.ServiceResponse;
import com.gic.commons.util.EntityUtil;
import com.gic.commons.util.PageHelperUtils;
import com.gic.enterprise.error.ErrorCode;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.evaluate.constant.Constants;
import com.gic.evaluate.dto.EvaluateDTO;
import com.gic.evaluate.dto.EvaluateReplyDTO;
import com.gic.evaluate.dto.UserReplyDTO;
import com.gic.evaluate.entity.TabEvaluate;
import com.gic.evaluate.entity.TabEvaluateReply;
import com.gic.evaluate.qo.EvaluateQO;
import com.gic.evaluate.service.EvaluateManageApiService;
import com.gic.evaluate.service.EvaluateReplyService;
import com.gic.evaluate.service.EvaluateService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Collections;
import java.util.List;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019-12-27 9:50
 */
@Service("evaluateManageApiService")
public class EvaluateManageApiServiceImpl implements EvaluateManageApiService {

    @Autowired
    private EvaluateService evaluateService;
    @Autowired
    private EvaluateReplyService evaluateReplyService;

    @Override
    public ServiceResponse<Page<EvaluateDTO>> listEvaluateForManage(EvaluateQO evaluateQO) {
        com.github.pagehelper.Page<TabEvaluate> evaluateList = evaluateService.listEvaluate(evaluateQO);
        Page<EvaluateDTO> page = PageHelperUtils.changePageHelperToCurrentPage(evaluateList, EvaluateDTO.class);
        return EnterpriseServiceResponse.success(page);
    }

    @Override
    public ServiceResponse<EvaluateDTO> getEvaluate(Integer enterpriseId, Integer evaluateId) {
        TabEvaluate evaluate = evaluateService.getEvaluate(enterpriseId, evaluateId);
        if (evaluate == null) {
            return EnterpriseServiceResponse.failure(ErrorCode.NOTEXISTS);
        }
        EvaluateDTO evaluateDTO = EntityUtil.changeEntityByJSON(EvaluateDTO.class, evaluate);
        List<TabEvaluateReply> tabReplyList = evaluateReplyService.listEvaluateReply(enterpriseId, evaluateId);
        List<EvaluateReplyDTO> replyDTOList = EntityUtil.changeEntityListByJSON(EvaluateReplyDTO.class, tabReplyList);
        evaluateDTO.setReplyList(replyDTOList);
        return EnterpriseServiceResponse.success(evaluateDTO);
    }

    @Override
    public ServiceResponse<Void> updateShowStatus(Integer enterpriseId, List<Integer> evaluateId, Integer showStatus) {
        this.evaluateService.updateShowStatus(enterpriseId, evaluateId, showStatus);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> updateTopHotStatus(Integer enterpriseId, Integer evaluateId, Integer topHotStatus) {
        this.evaluateService.updateTopHotStatus(enterpriseId, evaluateId, topHotStatus);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> updateMaliciousStatus(Integer enterpriseId, Integer evaluateId, Integer maliciousStatus) {
        this.evaluateService.updateMaliciousStatus(enterpriseId, evaluateId, maliciousStatus);
        if (Constants.OPEN.equals(maliciousStatus)) {
            this.evaluateService.updateShowStatus(enterpriseId, Collections.singletonList(evaluateId), Constants.CLOSE);
        } else if (Constants.CLOSE.equals(maliciousStatus)) {
            this.evaluateService.updateShowStatus(enterpriseId, Collections.singletonList(evaluateId), Constants.OPEN);
        }
        return EnterpriseServiceResponse.success();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ServiceResponse<Void> replyEvaluate(UserReplyDTO userReplyDTO) {
        this.evaluateReplyService.saveUserReplyEvaluate(userReplyDTO);
        EvaluateDTO evaluateDTO = new EvaluateDTO();
        evaluateDTO.setEvaluateId(userReplyDTO.getEvaluateId());
        evaluateDTO.setReplyStatus(Constants.CLOSE);
        this.evaluateService.updateEvaluate(evaluateDTO);
        return EnterpriseServiceResponse.success();
    }

    @Override
    public ServiceResponse<Void> delReply(Integer evaluateReplyId) {
        this.evaluateReplyService.delReply(evaluateReplyId);
        return EnterpriseServiceResponse.success();
    }

}
