package com.gic.evaluate.service.outer.impl;

import com.gic.api.base.commons.ServiceResponse;
import com.gic.enterprise.response.EnterpriseServiceResponse;
import com.gic.evaluate.qo.StoreScoreQO;
import com.gic.evaluate.qo.StoreTrendQO;
import com.gic.evaluate.service.EvaluateOverviewApiService;
import com.gic.evaluate.service.EvaluateService;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 *
 * @Description:
 * @author zhiwj
 * @date 2019-12-27 16:52
 */
@Service("evaluateOverviewApiService")
public class EvaluateOverviewApiServiceImpl implements EvaluateOverviewApiService {

    @Autowired
    private EvaluateService evaluateService;

    @Override
    public ServiceResponse<Map<String, Long>> chart1(Integer enterpriseId, String startTime, String endTime) {
        Map<String, Long> countMap = evaluateService.getTotalCountChart(enterpriseId, startTime, endTime);
        return EnterpriseServiceResponse.success(countMap);
    }

    @Override
    public ServiceResponse<List<Map<String, Long>>> chart2(Integer enterpriseId, String startTime, String endTime) {
        Map<String, Long> goodsCountMap = evaluateService.getGoodsCountChart(enterpriseId, startTime, endTime);
        Map<String, Long> storeCountMap = evaluateService.getStoreCountChart(enterpriseId, startTime, endTime);
        Map<String, Long> serviceCountMap = evaluateService.getServiceCountChart(enterpriseId, startTime, endTime);

        List<Map<String, Long>> list = new ArrayList<>();
        list.add(goodsCountMap);
        list.add(storeCountMap);
        list.add(serviceCountMap);

        return EnterpriseServiceResponse.success(list);
    }

    @Override
    public ServiceResponse<Map<String, List<Map<String, String>>>> chart3(Integer enterpriseId, String startTime, String endTime) {
        List<Map<String, String>> listTrendTotalEvaluate = this.evaluateService.listTrendTotalEvaluate(enterpriseId, startTime, endTime);
        List<Map<String, String>> listTrendGoodEvaluate = this.evaluateService.listTrendGoodEvaluate(enterpriseId, startTime, endTime);
        // todo order trend
        Map<String, List<Map<String, String>>> map = new HashMap<>();
        map.put("totalEvaluateList", listTrendTotalEvaluate);
        map.put("goodEvaluateList", listTrendGoodEvaluate);
        map.put("orderList", new ArrayList<>());
        return EnterpriseServiceResponse.success(map);
    }

    @Override
    public ServiceResponse<Map<String, List<Map<String, Object>>>> chart4(Integer enterpriseId, String startTime, String endTime) {
        List<Map<String, Object>> goodChart = this.evaluateService.evaluateGoodQuickChart(enterpriseId, startTime, endTime);
        List<Map<String, Object>> badChart = this.evaluateService.evaluateBadQuickChart(enterpriseId, startTime, endTime);
        Map<String, List<Map<String, Object>>> map = new HashMap<>();
        map.put("goodChart", goodChart);
        map.put("badChart", badChart);
        return EnterpriseServiceResponse.success(map);
    }

    @Override
    public ServiceResponse<List<Map<String, Object>>> listStoreScore(StoreScoreQO storeScoreQO) {
        List<Map<String, Object>> storeScoreList = this.evaluateService.listStoreScore(storeScoreQO);
        return EnterpriseServiceResponse.success(storeScoreList);
    }

    @Override
    public ServiceResponse<Map<String, Object>> getTotalStoreScore(StoreScoreQO storeScoreQO) {
        Map<String, Object> storeScore = this.evaluateService.getTotalStoreScore(storeScoreQO);
        return EnterpriseServiceResponse.success(storeScore);
    }

    @Override
    public ServiceResponse<List<Map<String, Object>>> listTrend(StoreTrendQO storeTrendQO) {
        List<Map<String, Object>> trendList = this.evaluateService.listTrend(storeTrendQO);
        if (CollectionUtils.isNotEmpty(trendList)) {
            List<Integer> storeIdList = trendList.stream().map(
                    e -> {
                        Object storeId = e.get("storeId");
                        return storeId == null ? null : Integer.valueOf(storeId.toString());
                    }
            ).collect(Collectors.toList());
            // todo order  通过storeIdList拿到order总数
        }
        return EnterpriseServiceResponse.success(trendList);
    }
}
